pub fn detect_format(header: &[u8]) -> ImageFormatExpand description
Detect image format from the first bytes of a file (magic bytes).
pub fn detect_format(header: &[u8]) -> ImageFormatDetect image format from the first bytes of a file (magic bytes).